diff --git a/configuration.nix b/configuration.nix
index ddb43e3..bc95ed6 100644
--- a/configuration.nix
+++ b/configuration.nix
@@ -38,8 +38,8 @@ with pkgs;
     shell = "${fish}/bin/fish";
   };
 
-  # Set vim as default editor
-  programs.vim.defaultEditor = true;
+  # Set neovim as default editor
+  programs.neovim.defaultEditor = true;
 
   # Set timezone and synchronize NTP
   time.timeZone = "Europe/Brussels";